<?php
/**
 * itcode Theme Customizer.
 *
 * @package WordPress
 * @package itcode
 * @since 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if ( ! function_exists( 'itcode_customize_register' ) ) {
	/**
	 * Register basic customizer support.
	 *
	 * @param object $wp_customize Customizer reference.
	 */
	function itcode_customize_register( $wp_customize ) {
		$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
		$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	}
}
add_action( 'customize_register', 'itcode_customize_register' );

if ( ! function_exists( 'itcode_theme_customize_register' ) ) {
	/**
	 * Register individual settings through customizer's API.
	 *
	 * @param WP_Customize_Manager $wp_customize Customizer reference.
	 */
	function itcode_theme_customize_register( $wp_customize ) {

		// Theme layout settings.

        $wp_customize->selective_refresh->add_partial( 'blogname', array(
            'selector' => '.site-title a',
            'render_callback' => 'itcode_customize_partial_blogname',
        ) );
        $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
            'selector' => '.site-description',
            'render_callback' => 'itcode_customize_partial_blogdescription',
        ) );
        // header_image
        $wp_customize->remove_section( 'header_image' );
        $wp_customize->add_section( 'header_image', array(
            'title'    => __( 'Header Image', 'itcode' ),
            'priority' => 5, // Before Toggle Top.
            'panel' => 'site_header_settings',
        ) );

        // title_tagline
        // site_general_settings
        $wp_customize->remove_section( 'title_tagline' );
        $wp_customize->add_section( 'title_tagline', array(
            'title'    => __( 'Site Ident', 'itcode' ),
            'priority' => 5, // Before Typography.
            'panel' => 'site_general_settings',
        ) );

        // background_image
        // site_general_settings
        $wp_customize->remove_section( 'background_image' );
        $wp_customize->add_section( 'background_image', array(
            'title'    => __( 'Site Background', 'itcode' ),
            'priority' => 40,
            'panel' => 'site_general_settings',
        ) );

        // colors
        // site_general_settings
        $wp_customize->remove_section( 'colors' );
        $wp_customize->add_section( 'colors', array(
            'title'    => __( 'Colors', 'itcode' ),
            'priority' => 50,
            'panel' => 'site_general_settings',
        ) );


        /**
         * Filter number of front page sections in Twenty Seventeen.
         *
         * @since Twenty Seventeen 1.0
         *
         * @param $num_sections integer
         */
        $num_sections = apply_filters( 'itcode_front_page_sections', 4 );
        // Create a setting and control for each of the sections available in the theme.
        for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
            $wp_customize->add_setting( 'panel_' . $i, array(
                'default'           => false,
                'sanitize_callback' => 'absint',
                'transport'         => 'postMessage',
            ) );

            $wp_customize->add_control( 'panel_' . $i, array(
                /* translators: %d is the front page section number */
                'label'          => sprintf( __( 'Front Page Section %d Content', 'itcode' ), $i ),
                'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'itcode' ) ),
                'section'        => 'static_front_page',
                'type'           => 'dropdown-pages',
                'allow_addition' => true,
                'active_callback' => 'itcode_is_static_front_page',
            ) );

            $wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
                'selector'            => '#panel' . $i,
                'render_callback'     => 'itcode_front_page_section',
                'container_inclusive' => true,
            ) );
        }

	}
} // endif function_exists( 'itcode_theme_customize_register' ).
add_action( 'customize_register', 'itcode_theme_customize_register' );

/**
 * get sidebars list
 */
if ( !function_exists( 'custom_get_sidebars_list' ) ) {
    function custom_get_sidebars_list() {
        global $wp_registered_sidebars;

        $sidebar_list = array();
        if (!empty($wp_registered_sidebars)) {
            foreach ($wp_registered_sidebars as $sidebar) {
                // todo rename
                $sidebar_list[$sidebar['id']] = $sidebar['name'];
            }
        };

        //var_dump($sidebar_list);
        return $sidebar_list;
    }
}

/**
 * Sanitize the page layout options.
 */
/*function itcode_sanitize_page_layout( $input ) {
    $valid = array(
        'one-column' => __( 'One Column', 'itcode' ),
        'two-column' => __( 'Two Column', 'itcode' ),
    );

    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    }

    return '';
}*/

/**
 * Sanitize the colorscheme.
 */
if ( ! function_exists( 'itcode_sanitize_colorscheme' ) ) {

    function itcode_sanitize_colorscheme( $input ) {
        $valid = array( 'light', 'dark', 'custom' );

        if ( in_array( $input, $valid ) ) {
            return $input;
        }

        return 'light';
    }
}

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Twenty Seventeen 1.0
 * @see itcode_customize_register()
 *
 * @return void
 */
if ( ! function_exists( 'itcode_customize_partial_blogname' ) ) {
    function itcode_customize_partial_blogname() {
        bloginfo( 'name' );
    }
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Twenty Seventeen 1.0
 * @see itcode_customize_register()
 *
 * @return void
 */
if ( ! function_exists( 'itcode_customize_partial_blogdescription' ) ) {
    function itcode_customize_partial_blogdescription() {
        bloginfo( 'description' );
    }
}

/**
 * Return whether we're previewing the front page and it's a static page.
 */
if ( ! function_exists( 'itcode_is_static_front_page' ) ) {
    function itcode_is_static_front_page() {
        return ( is_front_page() && ! is_home() );
    }
}

/**
 * Return whether we're on a view that supports a one or two column layout.
 */
if ( ! function_exists( 'itcode_is_view_with_layout_option' ) ) {
    function itcode_is_view_with_layout_option() {
        // This option is available on all pages. It's also available on archives when there isn't a sidebar.
        return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
    }
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
if ( ! function_exists( 'itcode_customize_preview_js' ) ) {
	/**
	 * Setup JS integration for live previewing.
	 */
	// look old customize-preview.js file
	function itcode_customize_preview_js() {
		wp_enqueue_script( 'itcode_customizer', get_template_directory_uri() . '/assets/js/customize-preview.js',
			array( 'customize-preview' ), '20130508', true );
	}
}
add_action( 'customize_preview_init', 'itcode_customize_preview_js' );


/**
 * Load dynamic logic for the customizer controls area.
 */
/*if ( ! function_exists( 'itcode_panels_js' ) ) {

    function itcode_panels_js() {
        wp_enqueue_script( 'itcode-customize-controls', get_theme_file_uri( '/assets/js/customize-controls.js' ), array(), '1.0', true );
    }
}
add_action( 'customize_controls_enqueue_scripts', 'itcode_panels_js' );*/




/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 */
if ( ! function_exists( 'compiler_action' ) ) {
    function compiler_action( ) {
        if ( !defined( 'FS_METHOD' ) ) {
            define( 'FS_METHOD', 'direct' );
        }

        require_once(ABSPATH . 'wp-admin/includes/file.php');
        WP_Filesystem();
        global $wp_filesystem;
        $template_dir = trailingslashit( get_template_directory() );

        ob_start();
        require $template_dir.'/sass' . '/config-scss.php';
        $_config_css = ob_get_clean();

        $target_file = $template_dir.'/sass/_config_theme.scss';

        if (is_writable(dirname($target_file)) == false){
            @chmod(dirname($target_file), 0755);
        }

        if (file_exists($target_file)) {
            if (is_writable($target_file) == false){
                @chmod($target_file, 0755);
            }
            @unlink($target_file);
        }

        $wp_filesystem->put_contents($target_file, $_config_css, FS_CHMOD_FILE);

        // Compile SCSS files
        if (!class_exists('scssc')) {
            require_once get_template_directory() . '/inc/scssphp/scss.inc.php';

        }

        $scss = new scssc();
        $scss->setImportPaths($template_dir . '/sass');


        if (get_theme_mod('site_enable_minifile_css', 1) == true ) {
            $scss->setFormatter('scss_formatter_crunched');
        } else {
            $scss->setFormatter('scss_formatter');
        }



        try {
            // theme_{blog_id}.css
            ob_start();
            echo $scss->compile('@import "theme_customizer.scss"');
            $_config_css = ob_get_clean();

            $filename = $template_dir.'assets/css/theme_customizer_'.get_current_blog_id().'.css';

            if (is_writable(dirname($filename)) == false){
                @chmod(dirname($filename), 0755);
            }

            if (file_exists($filename)) {
                if (is_writable($filename) == false){
                    @chmod($filename, 0755);
                }
                @unlink($filename);
            }

            $wp_filesystem->put_contents($filename, $_config_css, FS_CHMOD_FILE);
            //

            // compile main_style
            ob_start();
            echo $scss->compile('@import "main_style.scss"');
            $_main_style_css = ob_get_clean();

            $main_style = $template_dir.'assets/css/main_style.css';

            if (is_writable(dirname($main_style)) == false){
                @chmod(dirname($main_style), 0755);
            }

            if (file_exists($main_style)) {
                if (is_writable($main_style) == false){
                    @chmod($main_style, 0755);
                }
                @unlink($main_style);
            }

            $wp_filesystem->put_contents($main_style, $_main_style_css, FS_CHMOD_FILE);
            // end

            // compile theme
            ob_start();
            echo $scss->compile('@import "theme.scss"');
            $_compile_css = ob_get_clean();

            $theme = $template_dir.'assets/css/theme.css';

            if (is_writable(dirname($theme)) == false){
                @chmod(dirname($theme), 0755);
            }

            if (file_exists($theme)) {
                if (is_writable($theme) == false){
                    @chmod($theme, 0755);
                }
                @unlink($theme);
            }

            $wp_filesystem->put_contents($theme, $_compile_css, FS_CHMOD_FILE);
            // end

            // compile bootstrap4
             ob_start();
             echo $scss->compile('@import "bootstrap4.scss"');
             $_bs4_css = ob_get_clean();

             $bootstrap4 = $template_dir.'assets/css/bootstrap4.css';

             if (is_writable(dirname($bootstrap4)) == false){
                 @chmod(dirname($bootstrap4), 0755);
             }

             if (file_exists($bootstrap4)) {
                 if (is_writable($bootstrap4) == false){
                     @chmod($bootstrap4, 0755);
                 }
                 @unlink($bootstrap4);
             }

             $wp_filesystem->put_contents($bootstrap4, $_bs4_css, FS_CHMOD_FILE);
             // end





        }  catch (Exception $e) {
            //$error_log = $template_dir.'assets/css/error_compile.log';
            //$error_message = array (
                //'file' => basename($in),
            //    'message' => $e->getMessage(),
            //);
            //$wp_filesystem->put_contents($error_log, $error_message, FS_CHMOD_FILE);

        }


    }
}
// Function to test the compiler hook and demo CSS output.

add_action('customize_save_after', 'compiler_action', 100);











/**
 * Add the theme configuration
 */
Kirki::add_config( 'itcode_theme', array(
    'option_type' => 'theme_mod',
    'capability'  => 'edit_theme_options',
) );

$panel_priority = 10;
$section_priority = 10;

/**
 * Add the typography section
 */
Kirki::add_section( 'typography', array(
    'title'      => esc_attr__( 'Typography', 'itcode' ),
    'priority'   => $section_priority + 10,
    'capability' => 'edit_theme_options',
    'panel'     => 'site_general_settings',
) );
$field_priority = 10;
/**
 * Add the body-typography control
 */
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'typography',
    'settings'    => 'body_typography',
    'label'       => esc_attr__( 'Body Typography', 'itcode' ),
    'description' => esc_attr__( 'Select the main typography options for your site.', 'itcode' ),
    'help'        => esc_attr__( 'The typography options you set here apply to all content on your site.', 'itcode' ),
    'section'     => 'typography',
    'priority'    => $field_priority + 10,
    'default'     => array(
        'font-family'    => 'Open Sans',
        'variant'        => '400',
        'font-size'      => '16px',
        'line-height'    => '1.2',
        // 'letter-spacing' => '0',
        'color'          => '#333333',
    ),
    'output' => array(
        array(
            'element' => 'body',
        ),
    ),
) );
/**
 * Add the body-typography control
 */
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'typography',
    'settings'    => 'headers_typography',
    'label'       => esc_attr__( 'Headers Typography', 'itcode' ),
    'description' => esc_attr__( 'Select the typography options for your headers.', 'itcode' ),
    'help'        => esc_attr__( 'The typography options you set here will override the Body Typography options for all headers on your site (post titles, widget titles etc).', 'itcode' ),
    'section'     => 'typography',
    'priority'    => $field_priority + 10,
    'default'     => array(
        'font-family'    => 'Open Sans',
        'variant'        => '400',
        // 'font-size'      => '16px',
        // 'line-height'    => '1.5',
        // 'letter-spacing' => '0',
        // 'color'          => '#333333',
    ),
    'output' => array(
        array(
            'element' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', '.h1', '.h2', '.h3', '.h4', '.h5', '.h6' ),
        ),
    ),
) );




Kirki::add_panel( 'site_general_settings', array(
    'priority'    => $panel_priority + 10,
    'title'       => __( 'Theme Settings', 'itcode' ),
    'tooltip' => 'Site general settings panel',
) );

Kirki::add_section( 'site_general', array(
    'title'    => __( 'General', 'itcode' ),
    'panel' => 'site_general_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_back_to_top',
    'label'       => __( 'Enable Back To Top', 'itcode' ),
    'tooltip' => __( 'Enable/Disable Back to top button.', 'itcode' ),
    'section'  => 'site_general',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'itcode_back_to_top_place',
    'label'       => __( 'Button place', 'itcode' ),
    'tooltip' => __( "Choose button place", 'itcode' ),
    'section'     => 'site_general',
    'default'     => 'in_footer',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'in_footer' => __( 'In Footer', 'itcode' ),
        'in_nav'       => __( 'In Nav', 'itcode' )
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'site_enable_back_to_top',
            'operator' => '=',
            'value'    => '1',
        ),
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_rtl_mode',
    'label'       => __( 'Enable/Disable RTL mode', 'itcode' ),
    'tooltip' => __( 'Enable/Disable RTL mode.', 'itcode' ),
    'section'  => 'site_general',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_edit_link',
    'label'       => __( 'Enable Edit Link', 'itcode' ),
    'tooltip' => __( 'Enable Edit Link.', 'itcode' ),
    'section'  => 'site_general',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_minifile_css',
    'label'       => __( 'CSS Minifyer', 'itcode' ),
    'tooltip' => __( 'Enable this option to minify your styles. It\'ll decrease size of your style-sheet files to speed up your website.', 'itcode' ),
    'section'  => 'site_general',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_minifile_js',
    'label'       => __( 'JS Minifyer', 'itcode' ),
    'tooltip' => __( 'Enable this option to minify your JS. It\'ll decrease size of your style-sheet files to speed up your website.', 'itcode' ),
    'section'  => 'site_general',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_smooth_scroll',
    'label'       => __( 'Smooth Scroll', 'itcode' ),
    'tooltip' => __( 'By enabling this option, your page will have smooth scrolling effect.', 'itcode' ),
    'section'  => 'site_general',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/ // todo use archive infinfty scroll
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'site_enable_preloader',
    'label'       => __( 'Enable Preloader', 'itcode' ),
    'tooltip' => __( 'Enable/Disable Preloader.', 'itcode' ),
    'section'     => 'site_general',
    'default'     => 'none',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'none'       => 'None',
        'square-1'   => 'Square 01',
        'square-2'   => 'Square 02',
        'square-3'   => 'Square 03',
        'square-4'   => 'Square 04',
        'square-5'   => 'Square 05',
        'square-6'   => 'Square 06',
        'square-7'   => 'Square 07',
        'square-8'   => 'Square 08',
        'square-9'   => 'Square 09',
        'round-1'    => 'Round 01',
        'round-2'    => 'Round 02',
        'round-3'    => 'Round 03',
        'round-4'    => 'Round 04',
        'round-5'    => 'Round 05',
        'round-6'    => 'Round 06',
        'round-7'    => 'Round 07',
        'round-8'    => 'Round 08',
        'round-9'    => 'Round 09',
        'various-1'  => 'Various 01',
        'various-2'  => 'Various 02',
        'various-3'  => 'Various 03',
        'various-4'  => 'Various 04',
        'various-5'  => 'Various 05',
        'various-6'  => 'Various 06',
        'various-7'  => 'Various 07',
        'various-8'  => 'Various 08',
        'various-9'  => 'Various 09',
        'various-10' => 'Various 10',
    ),
) );*/// preloader
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'site_home_preloader_bg_color',
    'label'    => __('Preloader background color', 'itcode'),
    'tooltip' => __( 'Set Preloader background color.', 'itcode' ),
    'section'     => 'site_general',
    'default'     => '#bfbfbf',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'site_enable_preloader',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );*/// preloader
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'site_home_preloader_spinner_color',
    'label'    => __('Preloader spinner color', 'itcode'),
    'tooltip' => __( 'Pick a preloader spinner color.', 'itcode' ),
    'section'     => 'site_general',
    'default'     => '#bfbfbf',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'site_enable_preloader',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );*/// preloader

Kirki::add_section( 'site_maintenance', array(
    'title'    =>  __( 'Maintenance Mode', 'itcode' ),
    //'panel' => 'site_general_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );// maintenance
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'site_maintenance_mode',
    'label'      => __( 'Status', 'itcode' ),
    'tooltip' => __( 'Status of Maintenance Mode', 'itcode' ),
    'section'     => 'site_maintenance',
    'default'     => 'off',
    'priority'    => $field_priority + 10,
    'choices'    => array(
        'off' => __( 'Off', 'itcode' ),
        'on' => __( 'On', 'itcode' ),
        'custom' => __( 'On Custom Page', 'itcode' ),
    ),
) );// maintenance
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'dropdown-pages',
    'settings'    => 'site_maintenance_mode_custom_page',
    'label'          => __( 'Select page ', 'itcode' ),
    'tooltip'    => __( 'Select pages from the dropdowns.', 'itcode' ) ,
    'section'     => 'site_maintenance',
    'default'     => '',
    'priority'    => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'site_maintenance_mode',
            'operator' => '=',
            'value'    => 'custom',
        ),
    ),
) );// maintenance
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_var_debug',
    'label'       => __( 'Enable vsr debug', 'itcode' ),
    'section'  => 'site_maintenance',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );// maintenance

Kirki::add_section( 'site_layout', array(
    'title'    =>  __( 'Layout', 'itcode' ),
    'panel' => 'site_general_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'itcode_container_type',
    'label'       => __( 'Container Width', 'itcode' ),
    'tooltip' => __( "Choose between Bootstrap's container and container-fluid", 'itcode' ),
    'section'     => 'site_layout',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container'       => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container fluid', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'site_container_width',
    'label' => __( 'Container max-width', 'itcode' ),
    'tooltip' => esc_html__('You can define width of your website. ( Max width: 1170px )', 'itcode'),
    'section'     => 'site_layout',
    'priority'    => $field_priority + 10,
    'default'     => 960,
    'choices'     => array(
        'min'  => 640,
        'max'  => 1300,
        'step' => 100,
    ),
    /*array(
        'element'  => 'body',
        'property' => 'max-width',
        'units'    => 'px',
        'media_query' => '@media (max-width: 1200px)',
    ),*/
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'itcode_sidebar_position',
    'label'       => __( 'Sidebar Positioning', 'itcode' ),
    'tooltip' => __( "Set sidebar's default position. Can either be: right, left, both or none. Note: this can be overridden on individual pages.",
        'itcode' ),
    'section'     => 'site_layout',
    'default'     => 'right',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right' => __( 'Right', 'itcode' ),
        'left'  => __( 'Left', 'itcode' ),
        'both'  => __( 'Left & Right', 'itcode' ),
        'none'  => __( 'No sidebar', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'site_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'site_layout',
    'default'     => 'sidebar-1',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'site_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'site_layout',
    'default'     => 'sidebar-2',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar- 1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
) );// layout


Kirki::add_panel( 'site_header_settings', array(
    'priority'    => $panel_priority + 10,
    'title'       => __( 'Header', 'itcode' ),
    'tooltip' => __( 'Site header settings', 'itcode' ),
) );
Kirki::add_section( 'site_header_layout', array(
    'title'    =>  __( 'Header Layout', 'itcode' ),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_header_layout_style',
    'label'       => __( 'Header Layout Style', 'itcode' ),
    'tooltip' => __( 'Select the header layout style.', 'itcode' ),
    'section'  => 'site_header_layout',
    'priority' => $field_priority + 10,
    'default'  => 'full',
    'type'        => 'radio-image',
    'choices'     => array(
        'container' => get_template_directory_uri() . '/assets/images/theme-options/header-layout-boxed.png',
        'container-fluid' => get_template_directory_uri() . '/assets/images/theme-options/header-layout-float.png',
        'full' => get_template_directory_uri() . '/assets/images/theme-options/header-layout-wide.png',
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'spacing',
    'settings'    => 'header_padding',
    'label'       => __( 'Header padding', 'itcode' ),
    'section'     => 'site_header_layout',
    'default'     => array(
        'top'    => '0px',
        'bottom' => '0px',
        //'left'   => '10px',
        //'right'  => '10px',
    ),
    'priority'    => $field_priority + 10,
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-image',
    'settings'    => 'site_header_layout_type',
    'label'       => __( 'Header Layout', 'itcode' ),
    'tooltip' => __( 'Select a header layout option.', 'itcode' ),
    'section'     => 'site_header_layout',
    'default'     => 'header-1',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'header-1' => get_template_directory_uri() . '/assets/images/theme-options/header-1.jpg',
        'header-2' => get_template_directory_uri() . '/assets/images/theme-options/header-2.jpg',
        'header-3' => get_template_directory_uri() . '/assets/images/theme-options/header-3.jpg',
        'header-4' => get_template_directory_uri() . '/assets/images/theme-options/header-4.jpg',

    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'header_positon',
    'label'       => __( 'Header Position', 'itcode' ),
    'tooltip' =>  __( 'Set header position.', 'itcode' ),
    'section'  => 'site_header_layout',
    'type'        => 'radio-buttonset',
    'priority' => $field_priority + 10,
    'default'  => '0',
    'choices'     => array(
        '0' => __( 'Default', 'itcode' ),
        '1' => __( 'Overlay', 'itcode' ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'spacing',
    'settings'    => 'header_margin_top',
    'label'       => __( 'Header Margin top', 'itcode' ),
    'section'     => 'site_header_layout',
    'default'     => array(
        'top'    => '0px',
    ),
    'priority'    => $field_priority + 10,
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'header_bg',
    'label'       => __( 'Header background color', 'itcode' ),
    'tooltip' => __( 'Set header background color.', 'itcode' ),
    'section'     => 'site_header_layout',
    'default'     => '#0088CC',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'header_border_color',
    'label'       => __( 'Header Border Color', 'itcode' ),
    'tooltip' => __( 'Set Header Border Color.', 'itcode' ),
    'section'     => 'site_header_layout',
    'default'     => '#eee',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => false,
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_header_search_mode',
    'label'       => __( 'Header search', 'itcode' ),
    'tooltip' =>  __( 'Enable header search.', 'itcode' ),
    'section'  => 'site_header_layout',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_header_search_type_mode',
    'label'       => __( 'Header search type', 'itcode' ),
    'tooltip' =>  __( 'Choice header search type.', 'itcode' ),
    'section'  => 'site_header_layout',
    'type'        => 'radio-buttonset',
    'priority' => $field_priority + 10,
    'default'  => 'ajax',
    'choices'     => array(
        'standard' => __( 'Standard', 'itcode' ),
        'ajax' => __( 'Ajax', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'site_header_search_mode',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'slider',
    'settings'    => 'logo_max_height',
    'label'       => __( 'Logo Max Height', 'itcode' ),
    'tooltip' => __( 'If you would like to override the default logo height, then you can do so here.', 'itcode' ),
    'section'     => 'title_tagline',
    'priority'    => $field_priority + 10,
    'default'     => 60,
    'choices'     => array(
        'min'  => '10',
        'max'  => '300',
        'step' => '10',
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'slider',
    'settings'    => 'logo_width',
    'label'       => __( 'Logo width', 'itcode' ),
    'tooltip' => __( 'If you would like to override the default logo width, then you can do so here.', 'itcode' ),
    'section'     => 'title_tagline',
    'priority'    => $field_priority + 10,
    'default'     => 100,
    'choices'     => array(
        'min'  => '10',
        'max'  => '300',
        'step' => '10',
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'spacing',
    'settings'    => 'logo_padding',
    'label'       => __( 'Logo Padding', 'itcode' ),
    'tooltip' => __( 'Upload a light version of your logo here.', 'itcode' ),
    'section'     => 'title_tagline',
    'default'     => array(
        'top'    => '10px',
        'bottom' => '10px',
        'left'   => '0px',
        'right'  => '0px',
    ),
    'priority'    => $field_priority + 10,
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'light_logo',
    'label'       => __( 'Light Logo', 'itcode' ),
    'tooltip' => __( 'Upload a light version of your logo here.', 'itcode' ),
    'section'     => 'title_tagline',
    'default'     => '', // todo det link
    'priority'    => $field_priority + 10,
) );*/ // image
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'dark_logo',
    'label'       => __( 'Dark Logo', 'itcode' ),
    'tooltip' => __( 'Upload a dark version of your logo here', 'itcode' ),
    'section'     => 'title_tagline',
    'default'     => '',
    'priority'    => $field_priority + 10,
) );*/ // image
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'transparent_logo',
    'label'       => __( 'Transparent logo', 'itcode' ),
    'tooltip' => __( 'Choose an image file for your Transparent header logo here.', 'itcode' ),
    'section'     => 'title_tagline',
    'default'     => '', // todo det link
    'priority'    => $field_priority + 10,
) );*/ // image

Kirki::add_section( 'site_header_menu_setting', array(
    'title'    =>  __( 'Header Menu setting', 'itcode' ),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );


Kirki::add_section( 'site_mobile_header_setting', array(
    'title'    =>  __( 'Mobile Header', 'itcode' ),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-image',
    'settings'    => 'mobile_header_layout',
    'label'       => __( 'Header Layout', 'itcode' ),
    'tooltip' => __( 'Select header mobile layout', 'itcode' ),
    'section'     => 'site_mobile_header_setting',
    'default'     => 'header-mobile-1',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'header-mobile-1' => get_template_directory_uri() . '/assets/images/theme-options/header-mobile-layout-1.png',
        'header-mobile-2' => get_template_directory_uri() . '/assets/images/theme-options/header-mobile-layout-2.png',
        'header-mobile-3' => get_template_directory_uri() . '/assets/images/theme-options/header-mobile-layout-3.png',

    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'mobile_header_menu_type',
    'label'       => __( 'Mobile Menu Type', 'itcode' ),
    'tooltip' => __( 'Set menu type for mobile header', 'itcode' ),
    'section'     => 'site_mobile_header_setting',
    'default'     => 'dropdown',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'dropdown' => __( 'Dropdown Menu', 'itcode' ),
        'offcanvas' => __( 'Off-Canvas Menu', 'itcode' ),

    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'mobile_header_logo', // todo move to ident
    'label'       => __( 'Mobile Logo', 'itcode' ),
    'tooltip' => __( 'Upload your logo here.', 'itcode' ),
    'section'     => 'site_mobile_header_setting',
    'default'     => '',
    'priority'    => $field_priority + 10,
) );*/ // image
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'slider',
    'settings'    => 'logo_mobile_max_height',
    'label'       => __( 'Logo Mobile Max Height', 'itcode' ),
    'tooltip' => __( 'You can set a max height for the logo mobile here', 'itcode' ),
    'section'     => 'site_mobile_header_setting',
    'priority'    => $field_priority + 10,
    'default'     => 60,
    'choices'     => array(
        'min'  => '10',
        'max'  => '150',
        'step' => '10',
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'spacing',
    'settings'    => 'logo_mobile_padding',
    'label'       => __( 'Logo Top/Bottom Padding', 'itcode' ),
    'tooltip' => __( 'If you would like to override the default logo top/bottom padding, then you can do so here', 'itcode' ),
    'section'     => 'site_mobile_header_setting',
    'default'     => array(
        'top'    => '0px',
        'bottom' => '0px',
        //'left'   => '10px',
        //'right'  => '10px',
    ),
    'priority'    => $field_priority + 10,
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'mobile_header_top_bar',
    'label'       => __( 'Top Bar', 'itcode' ),
    'tooltip' => __( 'Enable Top bar.', 'itcode' ),
    'section'  => 'site_mobile_header_setting',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'mobile_header_stick',
    'label'       => __( 'Stick Mobile Header', 'itcode' ),
    'tooltip' => __( 'Enable Stick Mobile Header.', 'itcode' ),
    'section'  => 'site_mobile_header_setting',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'mobile_header_search_box',
    'label'       => __( 'Search Box', 'itcode' ),
    'tooltip' => __( 'Enable Search Box.', 'itcode' ),
    'section'  => 'site_mobile_header_setting',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'mobile_header_shopping_cart',
    'label'       => __( 'Shopping Cart', 'itcode' ),
    'tooltip' => __( 'Enable Shopping Cart', 'itcode' ),
    'section'  => 'site_mobile_header_setting',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );

Kirki::add_section( 'site_sticky_header_menu_opts', array(
    'title'    =>  __('Sticky Header NavBar', 'itcode'),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'header_sticky',
    'label'       => __( 'Sticky NavBar', 'itcode' ),
    'tooltip' => __( 'Sticky NavBar.', 'itcode' ),
    'section'  => 'site_sticky_header_menu_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'header_sticky_border',
    'label'       => __( 'Show/Hide Header Sticky border bottom', 'itcode' ),
    'tooltip' => __( 'Show/Hide Header Sticky border bottom', 'itcode' ),
    'section'  => 'site_sticky_header_menu_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
    'active_callback'    => array(
        array(
            'setting'  => 'header_sticky',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'sticky_logo', // todo move to ident
    'label'       => __('Sticky header logo', 'itcode'),
    'tooltip' => __('Use this option to upload a logo which will be used when header is on sticky state.', 'itcode'),
    'section'     => 'site_sticky_header_menu_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'header_sticky',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'sticky_logo_width',
    'label'       => __('Sticky header logo width', 'itcode'),
    'section'     => 'site_sticky_header_menu_opts',
    'default'     => 60,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 10,
        'max'  => 200,
        'step' => 10,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'header_sticky',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'header_sticky_scrolls',
    'label'       => __('Scrolls value to sticky the header', 'itcode'),
    'tooltip'     => __('Fill your desired amount which by scrolling that amount, sticky menu will appear.', 'itcode'),
    'section'     => 'site_sticky_header_menu_opts',
    'default'     => 300,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 50,
        'max'  => 800,
        'step' => 10,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'header_sticky',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );

Kirki::add_section( 'header_newsticker_opts', array(
    'title'    =>  __('News Ticker', 'itcode'),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'news_ticker',
    'label'    => __('News Ticker', 'itcode'),
    'tooltip'  => __( 'Show/Hide News Ticker', 'itcode' ),
    'section'  => 'header_newsticker_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',

) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'ticker_title',
    'label'    => __('News Ticker Title', 'itcode'),
    'section'  => 'header_newsticker_opts',
    'default'  => __( 'Latest Posts', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '=',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'ticker_show',
    'label'       => __('Show in', 'itcode'),
    'tooltip' => __( 'Set were show', 'itcode' ),
    'section'     => 'header_newsticker_opts',
    'default'     => '0',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        '0' => __( 'Home', 'itcode' ),
        '1' => __( 'All Pages', 'itcode' ),

    ),
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '=',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'ticker_cat',
    'label'       => __('Category', 'itcode'),
    'tooltip'     => __('Select specific category.', 'itcode'),
    'section'     => 'header_newsticker_opts',
    'default'     => '0',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        '0' => __( 'All', 'itcode' ), // todo create category list
        //'option-2' => esc_attr__( 'Option 2', 'my_textdomain' ),
        //'option-3' => esc_attr__( 'Option 3', 'my_textdomain' ),
        //'option-4' => esc_attr__( 'Option 4', 'my_textdomain' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '=',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'ticker_count',
    'label'       => __('Post Count', 'itcode'),
    'section'     => 'header_newsticker_opts',
    'default'     => 5,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 1,
        'max'  => 50,
        'step' => 1,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'ticker_effect',
    'label'       => __('Animation Type', 'itcode'),
    'tooltip' => __( 'Set Animation Type', 'itcode' ),
    'section'     => 'header_newsticker_opts',
    'default'     => 'reveal',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'fade' => __( 'Fade', 'itcode' ),
        'reveal' => __( 'Reveal', 'itcode' ),

    ),
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '=',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'ticker_speed',
    'label'       => __('Animation Speed	', 'itcode'),
    'section'     => 'header_newsticker_opts',
    'default'     => 1,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 1,
        'max'  => 10,
        'step' => 1,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'ticker_pause',
    'label'       => __('Pause On Items', 'itcode'),
    'section'     => 'header_newsticker_opts',
    'default'     => 2,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 1,
        'max'  => 10,
        'step' => 1,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'news_ticker',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );

Kirki::add_section( 'header_news_slider_opts', array(
    'title'    =>  __('News Slider', 'itcode'),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'news_slider',
    'label'    => __('News Slider', 'itcode'),
    'tooltip'  => __( 'Show/Hide News Slider', 'itcode' ),
    'section'  => 'header_news_slider_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',

) );

Kirki::add_section( 'site_toggle_top_area_opts', array(
    'title'    =>  __( 'Toggle Top Area', 'itcode' ),
    'panel' => 'site_header_settings',
    'tooltip' => __( 'It loads a small plus icon to the top right corner of your website.By clicking on it, it opens and shows your content that you set before.', 'itcode' ),
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'toggle_toparea_enable',
    'label'       => __( 'Enable Toggle Top Area', 'itcode' ),
    'tooltip' => __( 'It loads a small plus icon to the top right corner of your website.By clicking on it, it opens and shows your content that you set before.', 'itcode' ),
    'section'  => 'site_toggle_top_area_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'toggle_top_type',
    'label'       => __( 'Toggle Top Type', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => 'toggle',
    'priority'    => $field_priority + 10,
    //'active_callback' => 'compiler_action',
    'choices'     => array(
        'none' => __( 'Hide', 'itcode' ),
        'show' => __( 'Always Show', 'itcode' ),
        'toggle' => __( 'Toggle', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'toggle_top_sidebar',
    'label'       => __( 'Toggle Top  Sidebar', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => 'toggle_top_sidebar',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array( // todo fix to choice in list
        'toggle_top_sidebar' => esc_attr__( 'toggle_top_sidebar', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'toggle_top_wrapper_layout',
    'label'       => __( 'Toggle Top Wrapper Layout', 'itcode' ),
    'tooltip' => __( 'Select top drawer wrapper layout.', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-image',
    'settings'    => 'toggle_top_layout',
    'label'       => __( 'Toggle Top Layout', 'itcode' ),
    'tooltip' => __( 'Select the top column layout.', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => 'toggle-top-9',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'toggle-top-1' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-1.jpg',
        'toggle-top-2' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-2.jpg',
        'toggle-top-3' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-3.jpg',
        'toggle-top-4' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-4.jpg',
        'toggle-top-5' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-5.jpg',
        'toggle-top-6' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-6.jpg',
        'toggle-top-7' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-7.jpg',
        'toggle-top-8' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-8.jpg',
        'toggle-top-9' => get_template_directory_uri() . '/assets/images/theme-options/toggle-area-layout-9.jpg',

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'toggle_top_text_color',
    'label'       => __( 'Toggle Top text color', 'itcode' ),
    'tooltip' => __( 'Pick a text color for the Toggle Top.', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => '#c5c5c5',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'toggle_top_bg_mode',
    'label'       => __( 'Toggle Top Background Mode', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => 'color',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'Site Default', 'itcode' ),
        'color' => __( 'Color', 'itcode' ),
        'gradient' => __( 'Gradient', 'itcode' ),
        'image' => __( 'Image', 'itcode' ),

    ),
) );//toggle_top_bg_mode
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'toggle_top_bg_color',
    'label'       => __( 'Toggle Top background color', 'itcode' ),
    'tooltip' => __( 'Set Toggle Top background color.', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => '#2f2f2f',
    'priority'    => $field_priority + 10,
    //'sanitize_callback' => 'background_image_css',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'toggle_top_bg_mode',
            'operator' => '==',
            'value'    => 'color',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '#toggle-top-area',
            'property' => 'background-color',
            //'value_pattern' => '$',
            //'units'    => 'px',
        ),
    ),
) );//toggle_top_bg
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'toggle_top_bg_start_color',
    'label'    => __('Background Gradient Color Start', 'itcode'),
    'tooltip' => __('This option changes the background color.', 'itcode'),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => '#ffffff',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'toggle_top_bg_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '#toggle-top-area',
            'property' => 'background',/*background-image: linear-gradient( deg start stop );*/
            'value_pattern' => 'linear-gradient( '. get_theme_mod('toggle_top_bg_angle', 45 ) .'deg, $, '. get_theme_mod('toggle_top_bg_end_color', '#e0e0e0') .' );',
            //'units'    => 'px',
        ),
    ),
) );//toggle_top_bg
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'toggle_top_bg_end_color',
    'label'    => __('Background Gradient Color End', 'itcode'),
    'tooltip' => __('This option changes the background color.', 'itcode'),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => '#e0e0e0',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'toggle_top_bg_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '#toggle-top-area',
            'property' => 'background',/*background-image: linear-gradient( deg start stop );*/
            'value_pattern' => 'linear-gradient( '. get_theme_mod('toggle_top_bg_angle', 45 ) .'deg, '. get_theme_mod('toggle_top_bg_start_color', '#ffffff') .', $ );',
            //'units'    => 'px',
        ),
    ),
) );//toggle_top_bg
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'toggle_top_bg_angle',
    'label'    => __('Background Gradient Angle', 'itcode'),
    'tooltip' => __('This option changes the background color angle.', 'itcode'),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => 45,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 0,
        'max'  => 180,
        'step' => 1,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'toggle_top_bg_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
) );//toggle_top_bg
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'toggle_top_bg_image',
    'label'       => __( 'Toggle Top background image', 'itcode' ),
    'tooltip' => __( 'Upload your background image here.', 'itcode' ),
    'section'     => 'site_toggle_top_area_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'toggle_top_area_bg_color_mode',
            'operator' => '!==',
            'value'    => '1',
        ),
    ),
) ); // image*/

// end toggle top area

Kirki::add_section( 'site_topbar_opts', array(
    'title'    =>  __( 'TopBar', 'itcode' ),
    'panel' => 'site_header_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'header_topbar_enable',
    'label'       => __( 'Enable TopBar', 'itcode' ),
    'tooltip' => __('Top bar is the topmost location in your website that you can place special elements in.', 'itcode'),
    'section'  => 'site_topbar_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'topbar_background_color',
    'label'    => __('Background Color', 'itcode'),
    'tooltip' => __('This option changes the background color of Topbar.', 'itcode'),
    'section'     => 'site_topbar_opts',
    'default'     => '#bfbfbf',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'output' => array(
        'background-color' => '.top-bar',
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'topbar_fixed',
    'label'       => __('Fixed TopBar', 'itcode'),
    'section'  => 'site_topbar_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'topbar_search',
    'label'       => __( 'Search Bar', 'itcode' ),
    'tooltip' => __( 'Search Bar positions.', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'none',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'topbar_login',
    'label'       => __( 'Login Modal', 'itcode' ),
    'tooltip' => __( 'Login Modal positions.', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'none',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_login_text',
    'label'    => __('Login Modal Link Text', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  => __( 'Login / Register', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_login',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'topbar_contact',
    'label'       => __('Contact Modal', 'itcode'),
    'tooltip' => __( 'Contact Modal positions.', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'none',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'number',
    'settings' => 'topbar_cf7_id',
    'label'    => __('Contact Form ID', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  => '',   //__( 'Login / Register', 'itcode' ), // todo create filter for cf7
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_contact',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'topbar_info',
    'label'       => __('Contact Information', 'itcode'),
    'tooltip' => __( 'Contact Information positions.', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'none',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_address',
    'label'    => __('Contact Addresse', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  =>  '24 Hillyard St, London', //__( '1234', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_info',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_email',
    'label'    => __('Contact email', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  =>  __( 'info@site.com', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_info',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_phone',
    'label'    => __('Contact Phone Number', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  =>  __( '+1 234 56789', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_info',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'topbar_menu',
    'label'    => __('Topbar Menu', 'itcode'),
    'description' => __('you should create Topbar Menu from apearance > menus.', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'     => 'none',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'topbar_language',
    'label'    => __('Language Bar', 'itcode'),
    'description' => __('Polylang / WPML', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'     => 'none',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'topbar_custom_button',
    'label'    => __('Custom Button', 'itcode'),
    //'description' => __('Custom Button', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'     => 'none',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_button_text',
    'label'    => __('Button Text', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  =>  __( 'Text', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_custom_button',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_button_link',
    'label'    => __('Button Link URL', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  =>  __( 'http://site.com', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_custom_button',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'topbar_custom',
    'label'    => __('Custom Text', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'     => 'none',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'topbar_text',
    'label'    => __('Your Custom Text', 'itcode'),
    'description' => __('Insert any text', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'  =>  __( 'press any key', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'topbar_custom',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'topbar_social',
    'label'    => __('Social Icons', 'itcode'),
    'section'  => 'site_topbar_opts',
    'default'     => 'right',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'None', 'itcode' ),
        'left' => __( 'Left', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) ); // topbar
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'top_bar',
    'label'       => __( 'Show/Hide Top Bar', 'itcode' ),
    'section'  => 'site_topbar_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-image',
    'settings'    => 'top_bar_layout',
    'label'       => __( 'Top bar Layout', 'itcode' ),
    'tooltip' => __( 'Select the top bar column layout.', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'top-bar-1',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'top-bar-1' => get_template_directory_uri() . '/assets/images/theme-options/top-bar-layout-1.jpg',
        'top-bar-2' => get_template_directory_uri() . '/assets/images/theme-options/top-bar-layout-2.jpg',
        'top-bar-3' => get_template_directory_uri() . '/assets/images/theme-options/top-bar-layout-3.jpg',
        'top-bar-4' => get_template_directory_uri() . '/assets/images/theme-options/top-bar-layout-4.jpg',

    ),
    'active_callback'    => array(
        array(
            'setting'  => 'top_bar',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'top_bar_left_sidebar',
    'label'       => __( 'Top Left Sidebar', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'top_bar_left',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array( // todo fix to choice in list
        'top_bar_left' => esc_attr__( 'top_bar_left', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'top_bar',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'top_bar_right_sidebar',
    'label'       => __( 'Top Right Sidebar', 'itcode' ),
    'section'     => 'site_topbar_opts',
    'default'     => 'top_bar_right',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array( // todo fix to choice in list
        'top_bar_right' => esc_attr__( 'top_bar_right', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'top_bar',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/




Kirki::add_section( 'site_social_opts', array(
    'title'    =>  __( 'Social Networks', 'itcode' ),
    'panel' => 'site_general_settings',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_social_meta',
    'label'       => __( 'Enable Social Meta Tags', 'itcode' ),
    'tooltip' =>__( 'Enable the social meta head tag output.', 'itcode' ),
    'section'  => 'site_social_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // todo maybe move to general section?
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_social_sharing',
    'label'       => __( 'Enable Social Share', 'itcode' ),
    'tooltip' => __( 'Show the social sharing in blog posts.', 'itcode' ),
    'section'  => 'site_social_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_enable_social_sharing_404',
    'label'       => __( 'Enable Social share on page 404', 'itcode' ),
    'tooltip' => __( 'Show the social sharing in page 404.', 'itcode' ),
    'section'  => 'site_social_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/

Kirki::add_panel( 'site_pages_panel', array(
    'priority'    => $panel_priority + 10,
    'title'       => __( 'Pages', 'itcode' ),
) );

Kirki::add_section( 'title_opts', array(
    'title'    =>  __( 'Page Title', 'itcode' ),
    'panel' => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'enable_title',
    'label'       => __('Show Page Title', 'itcode'),
    'tooltip' => __('Show page title.', 'itcode'),
    'section'  => 'title_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );// enable_title
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_title_on_front',
    'label'       => __('Show Page Title On Front Page', 'itcode'),
    'tooltip' => __('Show page title on front page.', 'itcode'),
    'section'  => 'title_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );// enable_title
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'page_title_text_color',
    'label'    => __( 'Title Text Color', 'itcode' ),
    'tooltip' => __( 'Set Page Title Text Color.', 'itcode' ),
    'section'     => 'title_opts',
    'default'     => '#FFFFFF',
    'priority'    => $field_priority + 10,
    'transport'   => 'postMessage',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
    'output' => array(
        array(
            'element'  => 'h1.page-title',
            'property' => 'color',
        ),

    ),
) );// page_title_text_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'title_background_mode',
    'label'       => __( 'Title Background Mode', 'itcode' ),
    'section'     => 'title_opts',
    'default'     => 'color',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'Site Default', 'itcode' ),
        'color' => __( 'Color', 'itcode' ),
        'gradient' => __( 'Gradient', 'itcode' ),
        'image' => __( 'Image', 'itcode' ),

    ),
) );//title_background_mode
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'page_title_bg_color',
    'label'    => __( 'Page Title Background Color', 'itcode' ),
    'tooltip' => __( 'Set Page Title Background Color.', 'itcode' ),
    'section'     => 'title_opts',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => true,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.page-title-wrapper',
            'property' => 'background-color',
        ),

    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_background_mode',
            'operator' => '=',
            'value'    => 'color',
        ),
    ),
) );//page_title_bg_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'title_background_gradient_start_color',
    'label'    => __('Background Gradient Color Start', 'itcode'),
    'tooltip' => __('This option changes the background color of title.', 'itcode'),
    'section'     => 'title_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_background_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.page-title-wrapper',
            'property' => 'background',
            'value_pattern' => 'linear-gradient( '. get_theme_mod('title_background_gradient_angle', 45 ) .'deg, $, '. get_theme_mod('title_background_gradient_end_color', '#e0e0e0') .' );',
        ),
    ),
) );// title_background_gradient_start_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'title_background_gradient_end_color',
    'label'    => __('Background Gradient Color End', 'itcode'),
    'tooltip' => __('This option changes the background color of title.', 'itcode'),
    'section'     => 'title_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_background_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.page-title-wrapper',
            'property' => 'background',
            'value_pattern' => 'linear-gradient( '. get_theme_mod('title_background_gradient_angle', 45 ) .'deg, '. get_theme_mod('title_background_gradient_start_color', '#ffffff') .', $ );',
            //'units'    => 'px',
        ),
    ),
) );// title_background_gradient_end_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'title_background_gradient_angle',
    'label'    => __('Background Gradient Angle', 'itcode'),
    'tooltip' => __('This option changes the background color angle.', 'itcode'),
    'section'     => 'title_opts',
    'default'     => 45,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 0,
        'max'  => 180,
        'step' => 1,
    ),
    'transport'   => 'postMessage',
    'active_callback'    => array(
        array(
            'setting'  => 'title_background_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
) );
// todo add here title image background

/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'title_top_border',
    'label'       => __('Title Top Border', 'itcode'),
    'section'  => 'title_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'title_top_border_color',
    'label'    => __('Title Top Border Color', 'itcode'),
    'tooltip' => __('This option changes the color of title top border.', 'itcode'),
    'section'     => 'title_opts',
    'default'     => '#1f8bc1',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'output' => array(
        'border-color' => '.breadcrumbs-wrap',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_top_border',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'title_top_border_px',
    'label'    => __('Title Top Border px', 'itcode'),
    'section'     => 'title_opts',
    'default'     => 1,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 0,
        'max'  => 20,
        'step' => 1,
    ),
    'output' => array(
        'border-top' => '1px', // todo maybe error
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_top_border',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'title_bottom_border',
    'label'       => __('Title bottom Border', 'itcode'),
    'section'  => 'title_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'title_bottom_border_color',
    'label'    => __('Title bottom Border Color', 'itcode'),
    'tooltip' => __('This option changes the color of title bottom border.', 'itcode'),
    'section'     => 'title_opts',
    'default'     => '#cccccc',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'output' => array(
        'border-color' => '.breadcrumbs-wrap',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_bottom_border',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'title_bottom_border_px',
    'label'    => __('Title bottom Border px', 'itcode'),
    'section'     => 'title_opts',
    'default'     => 1,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 0,
        'max'  => 20,
        'step' => 1,
    ),
    'output' => array(
        'border-bottom' => '1px', // todo maybe error
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'title_bottom_border',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'title_position',
    'label'    => __('Title Position', 'itcode'),
    'section'  => 'title_opts',
    'default'     => 'left',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'left' => __( 'Left', 'itcode' ),
        'center' => __( 'Center', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'spacing',
    'settings'    => 'title_padding',
    'label'       =>  __('Title Padding', 'itcode'),
    'description' => __('default: 0 0 0 0', 'itcode'),
    'section'     => 'title_opts',
    'default'     => array(
        'padding-top'    => '0px',
        'padding-bottom' => '0px',
        'padding-left'   => '0px',
        'padding-right'  => '0px',
    ),
    'priority'    => $field_priority + 10,
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'spacing',
    'settings'    => 'title_margin',
    'label'       =>  __('Title margin', 'itcode'),
    'description' => __('default: 0 0 0 0', 'itcode'),
    'section'     => 'title_opts',
    'default'     => array(
        'margin-top'    => '0px',
        'margin-bottom' => '0px',
        'margin-left'   => '0px',
        'margin-right'  => '0px',
    ),
    'priority'    => $field_priority + 10,
) );*/
// end title settings
Kirki::add_section( 'breadcrumbs_opts', array(
    'title'    =>  __( 'Page Breadcrumbs', 'itcode' ),
    'panel' => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );// breadcrumbs_opts
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'enable_breadcrumbs',
    'label'       => __('Breadcrumbs', 'itcode'),
    'tooltip' => __('It allows users to keep track of their locations within pages.', 'itcode'),
    'section'  => 'breadcrumbs_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // enable_breadcrumbs
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'breadcrumbs_position',
    'label'    => __('Breadcrumbs Position', 'itcode'),
    'section'  => 'breadcrumbs_opts',
    'default'     => 'left',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'left' => __( 'Left', 'itcode' ),
        'center' => __( 'Center', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );// breadcrumbs_position
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_breadcrumbs_on_home',
    'label'       => __('Show on Home Page', 'itcode'),
    'tooltip' => __('It allows users to keep track of their locations within pages.', 'itcode'),
    'section'  => 'breadcrumbs_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );// show_breadcrumbs_on_home
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'breadcrumbs_text_color',
    'label'       => __('Breadcrumbs Text Color', 'itcode'),
    'tooltip'     => __('This option changes the text color of Breadcrumbs.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => false,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => 'ul.breadcrumbs li a', 'ul.breadcrumbs li:before', // todo fix before
            'property' => 'color',
        ),
    ),

) );// breadcrumbs_text_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'breadcrumbs_background_mode',
    'label'       => __( 'Breadcrumbs Background Mode', 'itcode' ),
    'section'     => 'breadcrumbs_opts',
    'default'     => 'color',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'none' => __( 'Site Default', 'itcode' ),
        'color' => __( 'Color', 'itcode' ),
        'gradient' => __( 'Gradient', 'itcode' ),
        'image' => __( 'Image', 'itcode' ),

    ),
) );// breadcrumbs_background_mode
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'page_breadcrumbs_bg_color',
    'label'    => __( 'Page Breadcrumbs Background Color', 'itcode' ),
    'tooltip' => __( 'Set Page Breadcrumbs Background Color.', 'itcode' ),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => true,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.row-breadcrumbs',
            'property' => 'background-color',
        ),

    ),
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_mode',
            'operator' => '=',
            'value'    => 'color',
        ),
    ),
) );//page_breadcrumbs_bg_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'breadcrumbs_background_gradient_start_color',
    'label'    => __('Background Gradient Color Start', 'itcode'),
    'tooltip' => __('This option changes the background color of Breadcrumbs.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.row-breadcrumbs',
            'property' => 'background',
            'value_pattern' => 'linear-gradient( '. get_theme_mod('breadcrumbs_background_gradient_angle', 45 ) .'deg, $, '. get_theme_mod('breadcrumbs_background_gradient_end_color', '#e0e0e0') .' );',
        ),
    ),
) );// breadcrumbs_background_gradient_start_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'breadcrumbs_background_gradient_end_color',
    'label'    => __('Background Gradient Color End', 'itcode'),
    'tooltip' => __('This option changes the background color of Breadcrumbs.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.row-breadcrumbs',
            'property' => 'background',
            'value_pattern' => 'linear-gradient( '. get_theme_mod('breadcrumbs_background_gradient_angle', 45 ) .'deg, '. get_theme_mod('breadcrumbs_background_gradient_start_color', '#ffffff') .', $ );',
            //'units'    => 'px',
        ),
    ),
) );// breadcrumbs_background_gradient_end_color
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'breadcrumbs_background_gradient_angle',
    'label'    => __('Background Gradient Angle', 'itcode'),
    'tooltip' => __('This option changes the background color angle.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => 45,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 0,
        'max'  => 180,
        'step' => 1,
    ),
    'transport'   => 'postMessage',
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_mode',
            'operator' => '==',
            'value'    => 'gradient',
        ),
    ),
) );
// todo add here title image background

/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'breadcrumbs_background_color',
    'label'    => __('Breadcrumbs Background Color', 'itcode'),
    'tooltip' => __('This option changes the background color of Breadcrumbs.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#1f8bc1',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'output' => array(
        'background-color' => '.breadcrumbs-wrap',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'enable_breadcrumbs',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/


/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'breadcrumbs_background_gradient',
    'label'       => __('Enable Background Gradient', 'itcode'),
    'section'  => 'breadcrumbs_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'breadcrumbs_background_gradient_start_color',
    'label'    => __('Breadcrumbs background Gradient Color Start', 'itcode'),
    'tooltip' => __('This option changes the background color of breadcrumbs.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'output' => array(
        'background-color' => '.breadcrumbs-wrap',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_gradient',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'breadcrumbs_background_gradient_end_color',
    'label'    => __('Breadcrumbs background Gradient Color End', 'itcode'),
    'tooltip' => __('This option changes the background color of breadcrumbs.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'alpha' => true,
    ),
    'output' => array(
        'background-color' => '.breadcrumbs-wrap',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_gradient',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'breadcrumbs_background_gradient_angle',
    'label'    => __('Background Gradient Angle', 'itcode'),
    'tooltip' => __('This option changes the background color angle.', 'itcode'),
    'section'     => 'breadcrumbs_opts',
    'default'     => 45,
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'min'  => 0,
        'max'  => 90,
        'step' => 1,
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'breadcrumbs_background_gradient',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) );*/



Kirki::add_section( 'site_std_pages', array(
    'title'    =>  __( 'Site std pages', 'itcode' ),
    //'tooltip' => __( 'Page 404 settings.', 'itcode' ),
    'panel' => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'itcode_container_type',
    'label'       => __( 'Layout', 'itcode' ),
    'tooltip' => __( 'Select Page Layout.', 'itcode' ),
    'section'     => 'site_std_pages',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); */// radio-buttonset
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_show_page_title',
    'label'       => __( 'Show Page Title', 'itcode' ),
    'tooltip' => __( 'Enable/Disable Page Title.', 'itcode' ),
    'section'  => 'site_std_pages',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'site_page_title_bg_image',
    'label'       => __( 'Page title background image', 'itcode' ),
    'tooltip' => __( 'Upload your background image here.', 'itcode' ),
    'section'     => 'site_std_pages',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); */// image
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'site_page_title_height',
    'label'       => esc_attr__( 'Page title height', 'itcode' ),
    'section'     => 'site_std_pages',
    'priority'    => $field_priority + 10,
    'default'     => 150,
    'choices'     => array(
        'min'  => 50,
        'max'  => 300,
        'step' => 10,
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'settings' => 'site_breadcrumbs_in_page_title',
    'label'       => __( 'Show Breadcrumbs In Page Title', 'itcode' ),
    'tooltip' => __( 'Enable/Disable Page Breadcrumbs.', 'itcode' ),
    'section'  => 'site_std_pages',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) );*/

Kirki::add_section( 'site_404_page', array(
    'title'    =>  __( 'Site 404 page', 'itcode' ),
    'tooltip' => __( 'Page 404 settings.', 'itcode' ),
    'panel' => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'hide_header_on_404_page',
    'label'       => __('Hide Header On Page', 'itcode'),
    'tooltip' => __( 'Enable/Disable Header on page', 'itcode' ),
    'section'  => 'site_404_page',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'hide_footer_on_404_page',
    'label'       => __('Hide Footer On Page', 'itcode'),
    'tooltip' => __( 'Enable/Disable Footer on page', 'itcode' ),
    'section'  => 'site_404_page',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'page_404_image',
    'label'       => __( 'Image', 'itcode' ),
    'tooltip' => __( 'Upload your image here.', 'itcode' ),
    'section'     => 'site_404_page',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'textarea',
    'settings' => 'subtitle_404',
    'label' => __( 'Subtitle 404', 'itcode' ),
    'section'  => 'site_404_page',
    'default'  => esc_attr__( 'It looks like nothing was found at this location. Maybe try a search?', 'itcode' ),
    'priority' => $field_priority + 10,
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'     => 'textarea',
    'settings' => 'site_404_text',
    'label' => __( 'Text To Display', 'itcode' ),
    'section'  => 'site_404_page',
    'default'  => esc_attr__( 'We&#039;re sorry, but the page you were looking for doesn&#039;t exist.', 'itcode' ),
    'priority' => $field_priority + 10,
) ); */// textarea
/*Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'site_copyright_404',
    'label' => __( 'Copyright', 'itcode' ),
    'tooltip' => esc_html__( 'Display copyright below page 404 footer', 'itcode' ),
    'section'  => 'site_404_page',
    'default'  => esc_attr__( 'Copyright 2017', 'itcode' ),
    'priority' => $field_priority + 10,
) ); // text*/

Kirki::add_section( 'page_opts', array(
    'title'    =>  __( 'Page Setting', 'itcode' ),
    'tooltip' => __( 'Page Setting.', 'itcode' ),
    'panel' => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'page_layout',
    'label'       => __( 'Page Layout', 'itcode' ),
    'tooltip' => __( 'Select Page Layout', 'itcode' ),
    'section'     => 'page_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'page_sidebar',
    'label'       => __( 'Page Sidebar Positioning', 'itcode' ),
    'tooltip' => __( "Set sidebar's default position. Can either be: right, left, both or none. Note: this can be overridden on individual pages.",
        'itcode' ),
    'section'     => 'page_opts',
    'default'     => 'right',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right' => __( 'Right', 'itcode' ),
        'left'  => __( 'Left', 'itcode' ),
        'both'  => __( 'Left & Right', 'itcode' ),
        'none'  => __( 'No sidebar', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'page_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'page_opts',
    'default'     => 'sidebar-1',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ), // todo fix on sidebars list
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'page_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'page_opts',
    'default'     => 'sidebar-2',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar- 1', 'itcode' ), // todo fix on sidebars list
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'page_sidebar_width',
    'label'       => __( 'Sidebar Width', 'itcode' ),
    'tooltip' => __( 'Set Sidebar width', 'itcode' ),
    'section'     => 'page_opts',
    'default'     => 'small',
    'priority'    => $field_priority + 10,
    'choices'    => array(
        'small'    => __( 'Small (1/4)', 'itcode' ),
        'large' => __( 'Large (1/3)', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'breadcrumbs_in_page_title',
    'label'       => __('Breadcrumbs', 'itcode'),
    'tooltip' => __( 'Enable/Disable Breadcrumbs in Page Title', 'itcode' ),
    'section'  => 'page_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'page_breadcrumbs_position',
    'label'    => __( 'Breadcrumbs Positons', 'itcode' ),
    'tooltip'  => __( 'Select Breadcrumbs Positons', 'itcode' ),
    'section'  => 'page_opts',
    'default'     => 'left',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'left' => __( 'Left', 'itcode' ),
        'center' => __( 'Center', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_page_title',
    'label'       => __( 'Show Page Title', 'itcode' ),
    'tooltip' => __( 'Enable/Disable Page Title', 'itcode' ),
    'section'  => 'page_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings' => 'page_title_position',
    'label'    => __( 'Page Title Positons', 'itcode' ),
    'tooltip'  => __( 'Select Page Title Positons', 'itcode' ),
    'section'  => 'page_opts',
    'default'     => 'left',
    'priority' => $field_priority + 10,
    'choices'     => array(
        'left' => __( 'Left', 'itcode' ),
        'center' => __( 'Center', 'itcode' ),
        'right' => __( 'Right', 'itcode' ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'page_title_height',
    'label'       => __( 'Page Title Height', 'itcode' ),
    'tooltip'  => __( 'Select Page Title Positons', 'itcode' ),
    'section'     => 'page_opts',
    'priority' => $field_priority + 10,
    'default'     => 100,
    'choices'     => array(
        'min'  => 10,
        'max'  => 500,
        'step' => 10,
    ),
) ); // number
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'page_title_bg_image',
    'label'       => __( 'Page Title Background', 'itcode' ),
    'tooltip'     => __( 'Upload page title background.', 'itcode' ),
    'section'     => 'page_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'page_comment',
    'label'       => __( 'Page Comment', 'itcode' ),
    'tooltip' => __( 'Enable/Disable page comment', 'itcode' ),
    'section'  => 'page_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle


Kirki::add_section( 'archive_opts', array(
    'title'    =>  __( 'Archive Pages Options', 'itcode' ),
    'tooltip' => __( 'Archive Pages Setting.', 'itcode' ),
    'panel' => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;

Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-image',
    'settings'    => 'archive_blog_template_type',
    'label'       => __( 'Page Template', 'itcode' ),
    'tooltip' => __( 'For styling your blog page you can choose among these template layouts.', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'list',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'list' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-1.png',
        'card' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-2.png',
        '3' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-3.png',
        '4' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-4.png',
        '5' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-5.png',
        '6' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-6.png',
        '7' => get_template_directory_uri() . '/assets/images/theme-options/blog-type-7.png',

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'archive_blog_excerptfull_enable',
    'label'    => __( 'Excerpt Or Full Blog Content', 'itcode' ),
    'tooltip'  => __( 'You can show all text of your posts in blog page or a fixed amount of characters to show for each post.', 'itcode' ),
    'section'  => 'archive_opts',
    'type'     => 'radio-buttonset',
    'priority' => $field_priority + 10,
    'default'  => '0',
    'choices'     => array(
        '0' => __( 'Excerpt', 'itcode' ),
        '1'  => __( 'Full', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'slider',
    'settings'    => 'archive_blog_excerpt_large',
    'label'       => __( 'Excerpt Length for Large Posts', 'itcode' ),
    'tooltip'     => __( 'Type the number of characters you want to show in the blog page for each post.', 'itcode' ),
    'section'     => 'archive_opts',
    'priority' => $field_priority + 10,
    'default'     => 50,
    'choices'     => array(
        'min'  => '1',
        'max'  => '500',
        'step' => '1',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_blog_excerptfull_enable',
            'operator' => '==',
            'value'    => '0',
        ),
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'slider',
    'settings'    => 'archive_blog_excerpt_list',
    'label'       => __( 'Excerpt Length for List Posts', 'itcode' ),
    'tooltip'     => __( 'Type the number of characters you want to show in the blog page for each post.', 'itcode' ),
    'section'     => 'archive_opts',
    'priority' => $field_priority + 10,
    'default'     => 50,
    'choices'     => array(
        'min'  => '1',
        'max'  => '500',
        'step' => '1',
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_blog_excerptfull_enable',
            'operator' => '==',
            'value'    => '0',
        ),
    ),
) );*/

Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_sidebar',
    'label'       => __( 'Sidebar', 'itcode' ),
    'tooltip' => __( 'Set Sidebar Style', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'right',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right' => __( 'Right', 'itcode' ),
        'left'  => __( 'Left', 'itcode' ),
        'both'  => __( 'Left & Right', 'itcode' ),
        'none'  => __( 'No sidebar', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_layout',
    'label'       => __( 'Layout', 'itcode' ),
    'tooltip' => __( 'Select Archive Layout', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_sidebar_width',
    'label'       => __( 'Sidebar Width', 'itcode' ),
    'tooltip'     => __( 'Set Sidebar width', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'small',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'small'   => __( 'Small (1/4)', 'itcode' ),
        'large'   => __( 'Large (1/3)', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'archive_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'sidebar-1',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ), // todo fix on sidebars list
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'archive_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'sidebar-2',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar- 1', 'itcode' ), // todo fix on sidebars list
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_paging_style',
    'label'       => __( 'Paging Style', 'itcode' ),
    'tooltip'     => __( 'Select archive paging style', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => 'default',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'default'    => __( 'Default', 'itcode' ),
        'load-more' => __( 'Load More', 'itcode' ),
        'infinity-scroll' => __( 'Infinity Scroll', 'itcode' ),

    ),
) ); // radio-buttonset

Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_archive_title',
    'label'    => __( 'Show Archive Title', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Archive Title', 'itcode' ),
    'section'  => 'archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'archive_blog_page_title',
    'label'    => __( 'Blog Page Title Custom Text', 'itcode' ),
    'section'  => 'archive_opts',
    'default'  => esc_attr__( 'Blog Archive', 'itcode' ),
    'priority' => $field_priority + 10,
) );

Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'archive_title_height',
    'label'       => __( 'Archive Title Height', 'itcode' ),
    'tooltip'  => __( 'You can set a height for the archive title here', 'itcode' ),
    'section'     => 'archive_opts',
    'priority' => $field_priority + 10,
    'default'     => 100,
    'choices'     => array(
        'min'  => 10,
        'max'  => 500,
        'step' => 10,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'archive_title_bg_image',
    'label'       => __( 'Archive Title Background', 'itcode' ),
    'tooltip'     => __( 'Upload archive title background.', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'breadcrumbs_in_archive_title',
    'label'    => __( 'Breadcrumbs', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Breadcrumbs in Archive Title', 'itcode' ),
    'section'  => 'archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'archive_blog_readmore_text',
    'label'    => __( 'Read More Text', 'itcode' ),
    'tooltip'  => __( 'You can set another name instead of read more link.', 'itcode' ),
    'section'  => 'archive_opts',
    'default'  => esc_attr__( 'Continue Reading', 'itcode' ),
    'priority' => $field_priority + 10,
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'archive_blog_featuredimage_enable',
    'label'    => __( 'Featured Image on Blog', 'itcode' ),
    'tooltip'  => __( 'By disabling this option, all blog feature images will be disappearing.', 'itcode' ),
    'section'  => 'archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'archive_blog_no_image',
    'label'    => __( 'Default Blank Featured Image', 'itcode' ),
    'section'  => 'archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
    'active_callback'    => array(
        array(
            'setting'  => 'archive_blog_featuredimage_enable',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'archive_post_no_image',
    'label'       => __( 'Custom Default Blank Featured Image', 'itcode' ),
    'tooltip'     => __( 'Upload Custom Image.', 'itcode' ),
    'section'     => 'archive_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'archive_blog_no_image',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'archive_blog_posttitle_enable',
    'label'    => __( 'Post Title on Blog', 'itcode' ),
    'tooltip'     => __( 'By disabling this option, all post title images will be disappearing.', 'itcode' ),
    'section'  => 'archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle
/**
 * array(
'title'		=> esc_html__( 'Post Title on Blog', 'itcode' ),
'subtitle'	=> esc_html__( 'By disabling this option, all post title images will be disappearing.','itcode' ),
'id'		=> 'itcode_webnus_blog_posttitle_enable',
'type'		=> 'switch',
'default'	=> '1',
'on'		=> esc_html__( 'On', 'itcode' ),
'off'		=> esc_html__( 'Off', 'itcode' ),
),
 */


/**
 * Blog page options
 */
/*Kirki::add_section( 'blog_page_opts', array(
    'title'    =>  __( 'Blog Page Options', 'itcode' ),
    'tooltip'  => __( 'Blog Page Options', 'itcode' ),
    'panel'    => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );*/
//$field_priority = 10;




Kirki::add_section( 'single_blog_opts', array(
    'title'    =>  __( 'Single Blog Options', 'itcode' ),
    'tooltip'  => __( 'Single Blog Options', 'itcode' ),
    'panel'    => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'single_blog_layout',
    'label'       => __( 'Layout', 'itcode' ),
    'tooltip'     => __( 'Select Single Blog Layout', 'itcode' ),
    'section'     => 'single_blog_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'single_blog_sidebar',
    'label'       => __( 'Sidebar', 'itcode' ),
    'tooltip' => __( 'Set Sidebar Style', 'itcode' ),
    'section'     => 'single_blog_opts',
    'default'     => 'right',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right' => __( 'Right', 'itcode' ),
        'left'  => __( 'Left', 'itcode' ),
        'both'  => __( 'Left & Right', 'itcode' ),
        'none'  => __( 'No sidebar', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'single_blog_sidebar_width',
    'label'       => __( 'Sidebar Width', 'itcode' ),
    'tooltip'     => __( 'Set Sidebar width', 'itcode' ),
    'section'     => 'single_blog_opts',
    'default'     => 'small',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'small'   => __( 'Small (1/4)', 'itcode' ),
        'large'   => __( 'Large (1/3)', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'single_blog_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'single_blog_opts',
    'default'     => 'sidebar-1',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ), // todo fix on sidebars list
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'single_blog_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'single_blog_opts',
    'default'     => 'sidebar-2',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar- 1', 'itcode' ), // todo fix on sidebars list
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_single_blog_title',
    'label'    => __( 'Show Single Blog Title', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Single Blog Title', 'itcode' ),
    'section'  => 'single_blog_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'single_blog_title_bg_image',
    'label'       => __( 'Single Blog Title Background', 'itcode' ),
    'tooltip'     => __( 'Upload single blog title background.', 'itcode' ),
    'section'     => 'single_blog_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'breadcrumbs_in_single_blog_title',
    'label'    => __( 'Breadcrumbs', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Breadcrumbs in Single Blog Title', 'itcode' ),
    'section'  => 'single_blog_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'single_blog_title_height',
    'label'       => __( 'Single Blog Title Height', 'itcode' ),
    'tooltip'  => __( 'You can set a height for the single blog title here', 'itcode' ),
    'section'     => 'single_blog_opts',
    'priority' => 90,
    'default'     => 100,
    'choices'     => array(
        'min'  => 10,
        'max'  => 500,
        'step' => 10,
    ),
) );



Kirki::add_section( 'woo_opts', array(
    'title'    =>  __( 'Woocommerce', 'itcode' ),
    'panel'    => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'woo_sidebar_enable',
    'label'    => __('Show/Hide Sidebar', 'itcode'),
    'tooltip'  => __( 'Show/Hide Sidebar on Shop Pages', 'itcode' ),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle // not found
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'woo_shop_title_enable',
    'label'    => __('Shop title Show/Hide', 'itcode'),
    'tooltip'  => __('Shop title Show/Hide', 'itcode'),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle // not found
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'woo_shop_title',
    'label'    => __('Shop page title', 'itcode'),
    'tooltip'  => __( 'Display Shop page title', 'itcode'),
    'section'  => 'woo_opts',
    'default'  => __( 'Shop', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'woo_shop_title_enable',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) ); // text // not found
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'woo_product_title_enable',
    'label'    => __('Product page title Show/Hide', 'itcode'),
    'tooltip'  => __('Shop title Show/Hide', 'itcode'),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle // not found
Kirki::add_field( 'itcode_theme', array(
    'type'     => 'text',
    'settings' => 'woo_product_title',
    'label'    => __('Shop product title', 'itcode'),
    'tooltip'  => __( 'Display Shop product title', 'itcode'),
    'section'  => 'woo_opts',
    'default'  => __( 'Product', 'itcode' ),
    'priority' => $field_priority + 10,
    'active_callback'    => array(
        array(
            'setting'  => 'woo_product_title_enable',
            'operator' => '==',
            'value'    => '1',
        ),
    ),
) ); // text // not found
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'add_to_cart_animation',
    'label'    => __( 'Add To Cart Animation', 'itcode' ),
    'tooltip'  => __( 'Enable Add To Cart Animation', 'itcode' ),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle // not found
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'product_per_page',
    'label'       => __( 'Products Per Page', 'itcode' ),
    'tooltip'  => __( 'This must be numeric or empty (default 12).', 'itcode' ),
    'section'     => 'woo_opts',
    'priority' => $field_priority + 10,
    'default'     => 12,
    'choices'     => array(
        'min'  => 1,
        'max'  => 100,
        'step' => 1,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'product_display_columns',
    'label'       => __( 'Product Display Columns', 'itcode' ),
    'tooltip'     => __( 'Choose the number of columns to display on shop/category pages.', 'itcode' ),
    'section'     => 'woo_opts',
    'priority' => $field_priority + 10,
    'default'     => 3,
    'choices'     => array(
        'min'  => 1,
        'max'  => 6,
        'step' => 1,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'product_show_rating',
    'label'    => __( 'Show Rating', 'itcode' ),
    'tooltip'  => __( 'Show/Hide Rating product', 'itcode' ),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'product_sale_flash_mode',
    'label'       => __( 'Sale Flash Mode', 'itcode' ),
    'tooltip'     => __( 'Chose Sale Flash Mode', 'itcode' ),
    'section'     => 'woo_opts',
    'default'     => 'text',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'text'   => __( 'Text', 'itcode' ),
        'percent'   => __( 'Percent', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'product_show_result_count',
    'label'    => __( 'Show Result Count', 'itcode' ),
    'tooltip'  => __( 'Show/Hide Result Count In Archive Product', 'itcode' ),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'product_show_catalog_ordering',
    'label'    => __( 'Show Catalog Ordering', 'itcode' ),
    'tooltip'  => __( 'Show/Hide Catalog Ordering', 'itcode' ),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'product_quick_view',
    'label'    => __( 'Quick View', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Quick View', 'itcode' ),
    'section'  => 'woo_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '0',
) ); // toggle

Kirki::add_section( 'woo_archive_opts', array(
    'title'    =>  __( 'Archive Product', 'itcode' ),
    'panel'    => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_product_layout',
    'label'       => __( 'Layout', 'itcode' ),
    'tooltip'     => __( 'Select Single Blog Layout', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_product_sidebar',
    'label'       => __( 'Set Archive Product Sidebar', 'itcode' ),
    'tooltip' => __( 'Set Sidebar Style', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'default'     => 'right',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right' => __( 'Right', 'itcode' ),
        'left'  => __( 'Left', 'itcode' ),
        'both'  => __( 'Left & Right', 'itcode' ),
        'none'  => __( 'No sidebar', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_product_sidebar_width',
    'label'       => __( 'Sidebar Width', 'itcode' ),
    'tooltip'     => __( 'Set Sidebar width', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'default'     => 'small',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'small'   => __( 'Small (1/4)', 'itcode' ),
        'large'   => __( 'Large (1/3)', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_product_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'archive_product_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'default'     => 'woocommerce',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ), // todo fix on sidebars list
        'woocommerce' => esc_attr__( 'Woocommerce', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_product_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'archive_product_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'default'     => 'woocommerce',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar- 1', 'itcode' ), // todo fix on sidebars list
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
        'woocommerce' => esc_attr__( 'Woocommerce', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_product_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_archive_product_title',
    'label'    => __( 'Show Archive Title', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Archive Product Title', 'itcode' ),
    'section'  => 'woo_archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'archive_product_title_height',
    'label'       => __( 'Archive Product Title Height', 'itcode' ),
    'tooltip'     => __( 'You can set a height for the archive product title here', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'priority'    => $field_priority + 10,
    'default'     => 100,
    'choices'     => array(
        'min'     => 10,
        'max'     => 500,
        'step'    => 10,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'breadcrumbs_in_archive_product_title',
    'label'    => __( 'Breadcrumbs in Archive Product Title', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Breadcrumbs in Archive Product Title', 'itcode' ),
    'section'  => 'woo_archive_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'archive_product_title_bg_image',
    'label'       => __( 'Archive Product Title Background', 'itcode' ),
    'tooltip'     => __( 'Upload archive product title background.', 'itcode' ),
    'section'     => 'woo_archive_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); // image

Kirki::add_section( 'single_product_opts', array(
    'title'    =>  __( 'Single Product', 'itcode' ),
    'panel'    => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'single_product_layout',
    'label'       => __( 'Single Product Layout', 'itcode' ),
    'tooltip'     => __( 'Select Single Product Layout', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'single_product_sidebar',
    'label'       => __( 'Single Product Sidebar', 'itcode' ),
    'tooltip'     => __( 'Set Single Product Sidebar', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => 'none',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right'   => __( 'Right', 'itcode' ),
        'left'    => __( 'Left', 'itcode' ),
        'both'    => __( 'Left & Right', 'itcode' ),
        'none'    => __( 'No sidebar', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'single_product_sidebar_width',
    'label'       => __( 'Sidebar Width', 'itcode' ),
    'tooltip'     => __( 'Set Sidebar width', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => 'small',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'small'   => __( 'Small (1/4)', 'itcode' ),
        'large'   => __( 'Large (1/3)', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'single_product_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'single_product_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => 'woocommerce',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ), // todo fix on sidebars list
        'woocommerce' => esc_attr__( 'Woocommerce', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'single_product_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'single_product_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => 'woocommerce',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar- 1', 'itcode' ), // todo fix on sidebars list
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
        'woocommerce' => esc_attr__( 'Woocommerce', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'single_product_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'show_single_product_title',
    'label'    => __( 'Show Single Title', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Single Product Title', 'itcode' ),
    'section'  => 'single_product_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'single_product_title_height',
    'label'       => __( 'Single Product Title Height', 'itcode' ),
    'tooltip'     => __( 'You can set a height for the single product title here', 'itcode' ),
    'section'     => 'single_product_opts',
    'priority'    => $field_priority + 10,
    'default'     => 100,
    'choices'     => array(
        'min'     => 10,
        'max'     => 500,
        'step'    => 10,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'breadcrumbs_in_single_product_title',
    'label'    => __( 'Breadcrumbs in Single Product Title', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Breadcrumbs in Single Product Title', 'itcode' ),
    'section'  => 'single_product_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'image',
    'settings'    => 'single_product_title_bg_image',
    'label'       => __( 'Single Product Title Background', 'itcode' ),
    'tooltip'     => __( 'Upload single product title background.', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => '',
    'priority'    => $field_priority + 10,
) ); // image
Kirki::add_field( 'itcode_theme', array(
    'settings' => 'related_product_enable',
    'label'    => __( 'Related Product Enable', 'itcode' ),
    'tooltip'  => __( 'Enable/Disable Related Product in Single Product Page', 'itcode' ),
    'section'  => 'single_product_opts',
    'type'     => 'toggle',
    'priority' => $field_priority + 10,
    'default'  => '1',
) ); // toggle
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'related_product_count',
    'label'       => __( 'Related Product Total Record', 'itcode' ),
    'tooltip'     => __( 'Total Record Of Related Product.', 'itcode' ),
    'section'     => 'single_product_opts',
    'priority' => $field_priority + 10,
    'default'     => 6,
    'choices'     => array(
        'min'  => 1,
        'max'  => 50,
        'step' => 1,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'number',
    'settings'    => 'related_product_display_columns',
    'label'       => __( 'Related Product Display Columns', 'itcode' ),
    'tooltip'     => __( 'Choose the number of columns to display on related product.', 'itcode' ),
    'section'     => 'single_product_opts',
    'priority' => $field_priority + 10,
    'default'     => 3,
    'choices'     => array(
        'min'  => 1,
        'max'  => 6,
        'step' => 1,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'related_product_condition',
    'label'       => __( 'Related Product Condition', 'itcode' ),
    'section'     => 'single_product_opts',
    'default'     => 'category',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'category' => __( 'Same Category', 'itcode' ),
        'tag' => __( 'Same Tag', 'itcode' ),

    ),
) ); // radio-buttonset


Kirki::add_section( 'portfolio_opts', array(
    'title'    =>  __( 'Portfolio', 'itcode' ),
    'panel'    => 'site_pages_panel',
    'priority' => $section_priority + 10,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '', // Rarely needed.
) );
$field_priority = 10;
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_portfolio_layout',
    'label'       => __( 'Layout', 'itcode' ),
    'tooltip'     => __( 'Select Single Blog Layout', 'itcode' ),
    'section'     => 'portfolio_opts',
    'default'     => 'container',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'full' => __( 'Full Width', 'itcode' ),
        'container' => __( 'Container', 'itcode' ),
        'container-fluid' => __( 'Container Fluid', 'itcode' ),

    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_portfolio_sidebar',
    'label'       => __( 'Set Archive Portfolio Sidebar', 'itcode' ),
    'tooltip' => __( 'Set Sidebar Style', 'itcode' ),
    'section'     => 'portfolio_opts',
    'default'     => 'right',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'right' => __( 'Right', 'itcode' ),
        'left'  => __( 'Left', 'itcode' ),
        'both'  => __( 'Left & Right', 'itcode' ),
        'none'  => __( 'No sidebar', 'itcode' ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'radio-buttonset',
    'settings'    => 'archive_portfolio_sidebar_width',
    'label'       => __( 'Sidebar Width', 'itcode' ),
    'tooltip'     => __( 'Set Sidebar width', 'itcode' ),
    'section'     => 'portfolio_opts',
    'default'     => 'small',
    'priority'    => $field_priority + 10,
    'choices'     => array(
        'small'   => __( 'Small (1/4)', 'itcode' ),
        'large'   => __( 'Large (1/3)', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_portfolio_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) ); // radio-buttonset
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'archive_portfolio_left_sidebar',
    'label'       => __( 'Left Sidebar', 'itcode' ),
    'section'     => 'portfolio_opts',
    'default'     => 'sidebar-1',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ),
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ), // todo fix on sidebars list
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_portfolio_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'select',
    'settings'    => 'archive_portfolio_right_sidebar',
    'label'       => __( 'Right Sidebar', 'itcode' ),
    'section'     => 'portfolio_opts',
    'default'     => 'sidebar-2',
    'priority'    => $field_priority + 10,
    'multiple'    => 1,
    'choices'     => array(
        'sidebar-1' => esc_attr__( 'sidebar-1', 'itcode' ), // todo fix on sidebars list
        'sidebar-2' => esc_attr__( 'sidebar-2', 'itcode' ),
    ),
    'active_callback'    => array(
        array(
            'setting'  => 'archive_portfolio_sidebar',
            'operator' => '!=',
            'value'    => 'none',
        ),
    ),
) );



//////////////////////
///
///
///
//woocommerce
if ( class_exists( 'WooCommerce' ) ) {
    //require_once get_template_directory() . '/inc/customizer/setups/woo-layout.php';
    //require_once get_template_directory() . '/inc/customizer/setups/woo-color.php';
}

// priority 150
require_once get_template_directory() . '/inc/customizer/customizer-projects.php';

// priority 160
require_once get_template_directory() . '/inc/customizer/customizer-footer.php';




Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'primary_color',
    'label'       => __( 'Primary Color', 'itcode' ),
    'tooltip' => __( 'Set Primary Color', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'secondary_color',
    'label'       => __( 'Secondary Color', 'itcode' ),
    'tooltip' => __( 'Set Secondary Color', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#222222',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );

/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'top_bar_bg_color',
    'label'       => __( 'Top Bar background color', 'itcode' ),
    'tooltip' => __( 'Set Top Bar background color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#F8F8F8',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'top_bar_text_color',
    'label'       => __( 'Top Bar text color', 'itcode' ),
    'tooltip' =>  __( 'Pick a text color for the Top Bar.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#222222',
    'priority'    => $field_priority + 10,
    //'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => '.top-bar',
            'property' => 'color',
            //'units'    => 'px',
        ),

    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'top_bar_border_color',
    'label'       => __( 'Top Bar border text color', 'itcode' ),
    'tooltip' =>  __( 'Pick a text border color for the Top Bar.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#eeeeee',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'text_color',
    'label'    => __( 'Text Color', 'itcode' ),
    'tooltip' => __( 'Set Text Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#8f8f8f',
    'priority'    => $field_priority + 10,
    //'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => 'body',
            'property' => 'color',
            //'units'    => 'px',
        ),

    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'bold_color',
    'label'    => __( 'Bolder Color', 'itcode' ),
    'tooltip' => __( 'Set Bolder Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#8f8f8f',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'heading_color',
    'label'       => __( 'Heading Color', 'itcode' ),
    'tooltip'     => __( 'Set Heading Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#222222',
    'priority'    => $field_priority + 10,
    //'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6' ),
            'property' => 'color',
            //'units'    => 'px',
        ),

    ),
) );

/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'border_color',
    'label'    => __( 'Border color', 'itcode' ),
    'tooltip' => __( 'Set Border color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#8f8f8f',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'footer_background_color',
    'label'    => __( 'Footer background color', 'itcode' ),
    'tooltip' => __( 'Set Footer background color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#8f8f8f',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/


Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'link_color',
    'label'    => __( 'Link Color', 'itcode' ),
    'tooltip' => __( 'Set Link Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#1e73be',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'menu_text_color',
    'label'    => __( 'Menu Text Color', 'itcode' ),
    'tooltip' => __( 'Set Menu Text Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#000000',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'menu_bg_color',
    'label'    => __( 'Menu Background Color', 'itcode' ),
    'tooltip' => __( 'Set Menu Background Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#ffffff',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'menu_sub_bg_color',
    'label'    => __( 'Sub Menu Background Color', 'itcode' ),
    'tooltip' => __( 'Set Sub Menu Background Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#111111',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'menu_sub_bg_hover_color',
    'label'    => __( 'Sub Menu Background Hover Color', 'itcode' ),
    'tooltip' => __( 'Set Sub Menu Background Hover Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#222222',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'menu_sub_text_color',
    'label'    => __( 'Sub Menu Text Color', 'itcode' ),
    'tooltip' => __( 'Set Sub Menu Text Color.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#AAAAAA',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );

Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'menu_link_color',
    'label'    => __( 'Header Menu Link', 'itcode' ),
    'tooltip' => __( 'Set Header Menu Link.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'scroll_to_top_hover_background_color',
    'label'    => __( 'Scroll to top', 'itcode' ),
    'tooltip' => __( 'Set Scroll to top.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'learnmore_link_color',
    'label'    => __( 'Learn more link', 'itcode' ),
    'tooltip' => __( 'Set Learn more link In IconBox.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    //'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
    'transport'   => 'postMessage',
    'output' => array(
        array(
            'element'  => 'a.read-more',
            'property' => 'color',
            //'units'    => 'px',
        ),

    ),
) );
Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'learnmore_hover_link_color',
    'label'    => __( 'Learn more hover link', 'itcode' ),
    'tooltip' => __( 'Set Learn more hover link In IconBox.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );
/*Kirki::add_field( 'itcode_theme', array(
    'type'        => 'color',
    'settings'    => 'resoponsive_menu_icon_color',
    'label'    => __( 'Responsive Menu Icon', 'itcode' ),
    'tooltip' => __( 'Set Appears in mobile & tablet view.', 'itcode' ),
    'section'     => 'colors',
    'default'     => '#2a2a2a',
    'priority'    => $field_priority + 10,
    'sanitize_callback' => 'sanitize_hex_color',
    'capability'        => 'edit_theme_options',
    'choices'     => array(
        'alpha' => false,
    ),
) );*/


