<?php
/**
 * Additional features to allow styling of the templates
 *
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package itcode
 * @since 1.0
 *
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */



/**
 * BODY CLASS
 */
if ( !function_exists( 'itcode_body_classes' ) ) {
    function itcode_body_classes( $classes ) {

        // Add class of group-blog to blogs with more than 1 published author.
        if ( is_multi_author() ) {
            $classes[] = 'group-blog';
        }

        // Add class of hfeed to non-singular pages.
        if ( ! is_singular() ) {
            $classes[] = 'hfeed';
        }

        // Add class if we're viewing the Customizer for easier styling of theme options.
        if ( is_customize_preview() ) {
            $classes[] = 'itcode-customizer';
        }

        // Add class on front page.
        if ( is_front_page() && 'posts' !== get_option( 'show_on_front' ) ) {
            $classes[] = 'itcode-front-page';
        }

        // Add a class if there is a custom header.
        if ( has_header_image() ) {
            $classes[] = 'has-header-image';
        }

        // Add class if sidebar is used.
        if ( is_active_sidebar( 'sidebar-1' ) && ! is_page() ) {
            $classes[] = 'has-sidebar';
        }

        // Add class for one or two column page layouts.
        if ( is_page() || is_archive() ) {
            if ( 'one-column' === get_theme_mod( 'page_layout' ) ) {
                $classes[] = 'page-one-column';
            } else {
                $classes[] = 'page-two-column';
            }
        }

        // Add class if the site title and tagline is hidden.
        if ( 'blank' === get_header_textcolor() ) {
            $classes[] = 'title-tagline-hidden';
        }

        // Get the colorscheme or the default if there isn't one.
        $colors = itcode_sanitize_colorscheme( get_theme_mod( 'colorscheme', 'light' ) );
        $classes[] = 'colors-' . $colors;

        // Removes tag class from the body_class array to avoid Bootstrap markup styling issues.
        foreach ( $classes as $key => $value ) {
            if ( $value == 'tag' ) {
                unset( $classes[ $key ] );
            }
        }

        return $classes;
    }// end itcode_body_classes

     add_filter( 'body_class', 'itcode_body_classes' );
}

/**
 * Count our number of active panels.
 *
 * Primarily used to see if we have any panels active, duh.
 */
function itcode_panel_count() {

	$panel_count = 0;

	/**
	 * Filter number of front page sections in Twenty Seventeen.
	 *
	 * @since Twenty Seventeen 1.0
	 *
	 * @param $num_sections integer
	 */
	$num_sections = apply_filters( 'itcode_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		if ( get_theme_mod( 'panel_' . $i ) ) {
			$panel_count++;
		}
	}

	return $panel_count;
}

/**
 * Checks to see if we're on the homepage or not.
 */
function itcode_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}




if ( ! function_exists( 'itcode_edit_link' ) ) :
    /**
     * Returns an accessibility-friendly link to edit a post or page.
     *
     * This also gives us a little context about what exactly we're editing
     * (post or page?) so that users understand a bit more where they are in terms
     * of the template hierarchy and their content. Helpful when/if the single-page
     * layout with multiple posts/pages shown gets confusing.
     */
    function itcode_edit_link() {

        $link = edit_post_link(
            sprintf(
            /* translators: %s: Name of current post */
                __( 'Edit<span class="screen-reader-text"> "%s"</span>', 'itcode' ),
                get_the_title()
            ),
            '<span class="edit-link">',
            '</span>'
        );

        return $link;
    }
endif;



/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function itcode_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
    }
}
add_action( 'wp_head', 'itcode_pingback_header' );


// Filter custom logo with correct classes.
//add_filter( 'get_custom_logo', 'change_logo_class' );
//
//if ( ! function_exists( 'change_logo_class' ) ) {
//	/**
//	 * Replaces logo CSS class.
//	 *
//	 * @param string $html Markup.
//	 *
//	 * @return mixed
//	 */
//	function change_logo_class( $html ) {
//
//		$html = str_replace( 'class="custom-logo"', 'class="img-responsive"', $html );
//		$html = str_replace( 'class="custom-logo-link"', 'class="navbar-brand custom-logo-link"', $html );
//		$html = str_replace('alt=""', 'title="Home" alt="logo"' , $html );
//
//		return $html;
//	}
//}
